@@ -25,6 +25,16 @@ QAttachmentWidget::~QAttachmentWidget()
 
 }
 
+void QAttachmentWidget::setAudioType()
+{
+	ui.lAttachmentIcon->setPixmap(QPixmap(":/IconAdd/file-audio.png"));
+}
+
+void QAttachmentWidget::setPdfType()
+{
+	ui.lAttachmentIcon->setPixmap(QPixmap(":/IconAdd/file-pdf.png"));
+}
+
 QByteArray QAttachmentWidget::toPng(QAttachmentWidget* widget)
 {
 	QPixmap p = QPixmap::grabWidget(widget);
