@@ -1,8 +1,8 @@
 #include "QNewNotebookDialog.h"
 #include <QMessageBox>
 
-QNewNotebookDialog::QNewNotebookDialog(QvernoteAPI* hEvernote, QWidget *parent)
-    : QDialog(parent), m_hEvernote(hEvernote)
+QNewNotebookDialog::QNewNotebookDialog(QWidget *parent)
+    : QDialog(parent)
 {
 	ui.setupUi(this);
 
@@ -21,7 +21,7 @@ void QNewNotebookDialog::createNewNotebook()
 	setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
 
-	if(m_hEvernote->createNewNotebook(
+	if(QvernoteAPI::Instance()->createNewNotebook(
 			ui.leNotebookName->text().toStdString(),
 			ui.cbDefault->isChecked(),
 			ui.cbPublic->isChecked()) == false)
