@@ -27,7 +27,6 @@
 #include "QNotesView.h"
 #include "QClickableLabel.h"
 #include <QDebug>
-#include "QThumbnailCreator.h"
 
 class QNoteSnapshotWidget : public QWidget
 {
@@ -67,15 +66,15 @@ public:
 	}
 
 	void render(Guid guid) {
-		/*m_WebView = new QWebView();
-		m_WebView->settings()->setAttribute(QWebSettings::LocalContentCanAccessRemoteUrls, false);
-		QObject::connect(m_WebView, SIGNAL(loadFinished(bool)), this, SLOT(setNoteSnapshot()));
-		QObject::connect(m_WebView, SIGNAL(loadProgress(int)), this, SLOT(updateLoadProgress(int)));
-		m_WebView->setHtml(html);*/
-		thumbnailCreator = new QThumbnailCreator(guid, false);
-		QObject::connect(thumbnailCreator, SIGNAL(snapshotReady()), this, SLOT(setNoteSnapshot()), Qt::QueuedConnection);
-		QObject::connect(thumbnailCreator, SIGNAL(loadProgress(int)), this, SLOT(updateLoadProgress(int)));
-		thumbnailCreator->start();
+		Note note;
+		note.guid = guid;
+		QvernoteAPI::Instance()->getNoteContent(note);
+		enmlReader = new QEnmlReader(note);
+		enmlReader->setLoadExternalReferences(false);
+		enmlReader->parse();
+		QObject::connect(enmlReader->getThumbnailCreator(), SIGNAL(snapshotReady()), this, SLOT(setNoteSnapshot()), Qt::QueuedConnection);
+		QObject::connect(enmlReader->getThumbnailCreator(), SIGNAL(loadProgress(int)), this, SLOT(updateLoadProgress(int)));
+		enmlReader->createThumbnail();
 	}
 
 	void render(QPixmap* thumbnail) {
@@ -92,14 +91,8 @@ public:
 public slots:
 	void setNoteSnapshot()
 	{
-		//QPixmap m_Snapshot(m_WebView->size());
-		//m_WebView->setRenderHint(QPainter::SmoothPixmapTransform, true);
-		//m_WebView->render(&m_Snapshot);
-		//QPixmap m_Snapshot = QPixmap::grabWidget(m_WebView);
-		//m_SnapshotImage = new QPixmap(m_Snapshot.scaled(QSize(180,150), Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation));
-		m_SnapshotImage = new QPixmap(thumbnailCreator->getThumbnail());
-		delete thumbnailCreator;
-		//delete m_WebView;
+		m_SnapshotImage = new QPixmap(enmlReader->getThumbnailCreator()->getThumbnail());
+		delete enmlReader;
 		emit snapshotReady();
 	}
 
@@ -116,7 +109,7 @@ private:
 	QPixmap*	m_SnapshotImage;
 	int			m_loadProgress;
 	bool		hasAttachment;
-	QThumbnailCreator* thumbnailCreator;
+	QEnmlReader* enmlReader;
 };
 
 class QNoteWidget : public QClickableLabel
