@@ -1,6 +1,7 @@
 #include "QNoteSearchDialog.h"
 #include "QvernoteView.h"
 #include "QTagSelectorDialog.h"
+#include "QNotebookPickList.h"
 
 QNoteSearchDialog::QNoteSearchDialog(QWidget *parent)
     : QDialog(parent), m_parent(parent)
@@ -9,6 +10,7 @@ QNoteSearchDialog::QNoteSearchDialog(QWidget *parent)
 
 	QObject::connect(ui.pbStartSearch, SIGNAL(clicked()), this, SLOT(searchNote()));
 	QObject::connect(ui.pbSearchTags, SIGNAL(clicked()), this, SLOT(openTagSelectionDialog()));
+	QObject::connect(ui.pbSearchNotebook, SIGNAL(clicked()), this, SLOT(openNotebookSelectionDialog()));
 }
 
 QNoteSearchDialog::~QNoteSearchDialog()
@@ -27,7 +29,7 @@ void QNoteSearchDialog::searchNote()
 		tagGuids.push_back(tagData[1].toStdString());
 	}
 
-	((QvernoteView*)m_parent)->searchNote(ui.leSearchString->text(), tagGuids);
+	((QvernoteView*)m_parent)->searchNote(ui.leSearchString->text(), tagGuids, (selectedNotebook.size() > 1)? selectedNotebook[1].toStdString() : "");
 	close();
 }
 
@@ -45,6 +47,18 @@ void QNoteSearchDialog::openTagSelectionDialog()
 		ui.pbSearchTags->setText("Tags");
 }
 
+void QNoteSearchDialog::openNotebookSelectionDialog()
+{
+	QNotebookPickList dlg("All Notebooks", this);
+	if(dlg.exec() == QDialog::Rejected)
+		return;
+
+	selectedNotebook.append(dlg.getSelectedName());
+	selectedNotebook.append(dlg.getSelectedGuid());
+
+	ui.pbSearchNotebook->setText(selectedNotebook[0]);
+}
+
 void QNoteSearchDialog::setTag(bool , Tag tag)
 {
 	foreach(QStringList tagData, selectedTagsList) { if(tagData[0].toStdString() == tag.name) return; }
