@@ -12,15 +12,22 @@
 #include "QMaemoTextSelectionSupressor.h"
 #endif
 
+//#ifdef Q_WS_MAEMO_5
+//#include "QMaemoMapViewDialog.h"
+//#else
+#include "QGoogleMapViewDialog.h"
+//#endif
+
 QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
     : QvernoteWindow(parent), m_Note(note), isNavControlsVisible(false)
 {
 	ui.setupUi(this);
 
-	QObject::connect(ui.wvNoteView, SIGNAL(loadFinished(bool)), this, SLOT(resizeWebView()), Qt::QueuedConnection);
+	QObject::connect(ui.wvNoteView, SIGNAL(loadFinished(bool)), this, SLOT(noteLoadFinished()), Qt::QueuedConnection);
 	m_hEvernote = QvernoteAPI::Instance();
 	enmlReader = shared_ptr<QEnmlReader>(new QEnmlReader());
-
+	//ui.wvNoteView->setVisible(false);
+	//ui.gridLayout_2->setRowMinimumHeight(3, 400);
 	//loadNote();
 	ui.wvNoteView->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
 	ui.wvNoteView->page()->setPreferredContentsSize(QSize(800, 600));
@@ -28,6 +35,10 @@ QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
 
 	webViewSlide = new QPropertyAnimation(ui.wvNoteView, "geometry");
 	webViewSlide->setDuration(100);
+
+	ui.lFavorite->setBorderEnabled(false);
+	ui.lFavorite->setClickAnimEnabled(false);
+
 	//QObject::connect(webViewSlide, SIGNAL(finished()), this, SLOT(backgroundLoad()));
 
 #ifdef Q_WS_MAEMO_5
@@ -62,6 +73,11 @@ QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
 	noteViewMenu->addAction(actNext);
 	noteViewMenu->addAction(actPrev);
 	this->setMenuBar(noteViewMenu);
+	ui.lFavorite->setStyleSheet("background-color: #424142;");
+	ui.lNoteTitle->setStyleSheet("background-color: #424142;");
+	ui.lNotebookName->setStyleSheet("background-color: #424142;");
+	ui.lTagIcon->setStyleSheet("background-color: #424142;");
+	ui.lNoteTags->setStyleSheet("background-color: #424142;");
 	initNavigationControls();
 
 	QObject::connect(actEditNote, SIGNAL(triggered()), SLOT(startEditor()));
@@ -108,28 +124,10 @@ bool QNoteViewWindow::loadNote()
 
 void QNoteViewWindow::displayNote()
 {
+	//ui.wvNoteView->setVisible(false);
 	enmlReader->parse(m_Note);
 	ui.wvNoteView->setHtml(enmlReader->getHtml());
 
-	webViewSlide->stop();
-	if(slideLeft)
-		webViewSlide->setStartValue(QRect(savedWebViewGeometry.topRight(), savedWebViewGeometry.size()));
-	else
-		webViewSlide->setStartValue(QRect(savedWebViewGeometry.topLeft() - QPoint(savedWebViewGeometry.width(), 0), savedWebViewGeometry.size()));
-
-	webViewSlide->setEndValue(savedWebViewGeometry);
-	webViewSlide->start();
-
-	if(QvernoteStorage::Instance()->isNoteFavorite(m_Note.guid))
-	{
-		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-full-48.png"));
-		ui.lFavorite->setProperty("isFavorite", QVariant(true));
-	}
-	else
-	{
-		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-empty-48.png"));
-		ui.lFavorite->setProperty("isFavorite", QVariant(false));
-	}
 	ui.scrollArea->ensureVisible(0, 0);
 }
 
@@ -143,6 +141,22 @@ void QNoteViewWindow::startEditor()
 	m_pNoteEditWindow->show();
 }
 
+void QNoteViewWindow::noteLoadFinished()
+{
+
+	QObject::disconnect(webViewSlide, SIGNAL(finished()), this, SLOT(startBackgroundTask()));
+	QObject::connect(webViewSlide, SIGNAL(finished()), this, SLOT(resizeWebView()));
+	//webViewSlide->stop();
+	if(slideLeft)
+		webViewSlide->setStartValue(QRect(savedWebViewGeometry.topRight(), savedWebViewGeometry.size()));
+	else
+		webViewSlide->setStartValue(QRect(savedWebViewGeometry.topLeft() - QPoint(savedWebViewGeometry.width(), 0), savedWebViewGeometry.size()));
+
+	webViewSlide->setEndValue(savedWebViewGeometry);
+	webViewSlide->start();
+	//ui.wvNoteView->setVisible(true);
+}
+
 void QNoteViewWindow::resizeWebView()
 {
 	QSize s = ui.wvNoteView->page()->mainFrame()->contentsSize();
@@ -229,11 +243,22 @@ void QNoteViewWindow::zoomoutView()
 
 void QNoteViewWindow::emailNote()
 {
-	QEmailNoteDialog* pDlg;
+	QEmailNoteDialog pDlg(m_Note, m_hEvernote, this);
+	pDlg.exec();
+}
 
-	pDlg = new QEmailNoteDialog(m_Note, m_hEvernote, this);
-	pDlg->exec();
-	delete pDlg;
+void QNoteViewWindow::showNoteMap()
+{
+//#ifdef Q_WS_MAEMO_5
+//	QMaemoMapViewDialog pDlg(m_Note);
+//	pDlg.exec();
+//#else
+	if(QvernoteSettings::Instance()->getMapsProvider() == QvernoteSettings::MP_GOOGLE)
+	{
+		QGoogleMapViewDialog pDlg(m_Note);
+		pDlg.exec();
+	}
+//#endif
 }
 
 void QNoteViewWindow::loadNextNote()
@@ -267,6 +292,17 @@ void QNoteViewWindow::backgroundLoad()
 	setProgressIndicator(true);
 	//ui.wvNoteView->setHtml("<center><font size=\"18\" color=\"#37b4fc\">Loading...</font></center>");
 	//ui.wvNoteView->setHtml("");
+	if(QvernoteStorage::Instance()->isNoteFavorite(m_Note.guid))
+	{
+		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-full-48.png"));
+		ui.lFavorite->setProperty("isFavorite", QVariant(true));
+	}
+	else
+	{
+		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-empty-48.png"));
+		ui.lFavorite->setProperty("isFavorite", QVariant(false));
+	}
+
 	ui.lNoteTitle->setText(QString::fromUtf8(m_Note.title.c_str()));
 
 	if(m_hEvernote->getNotebookByGuid(notebook, m_Note.notebookGuid))
@@ -287,6 +323,7 @@ void QNoteViewWindow::backgroundLoad()
 	else
 		ui.lNoteTags->setText(tagList);
 
+	QObject::connect(webViewSlide, SIGNAL(finished()), this, SLOT(startBackgroundTask()));
 	webViewSlide->setStartValue(ui.wvNoteView->geometry());
 	if(slideLeft)
 		webViewSlide->setEndValue(QRect(ui.wvNoteView->geometry().topLeft() - QPoint(ui.wvNoteView->size().width(), 0), ui.wvNoteView->size()));
@@ -295,7 +332,7 @@ void QNoteViewWindow::backgroundLoad()
 
 	webViewSlide->start();
 
-	m_pBackgroundJob->start();
+	//m_pBackgroundJob->start();
 }
 
 void QNoteViewWindow::initNavigationControls()
@@ -342,12 +379,19 @@ void QNoteViewWindow::initNavigationControls()
 	clEmail->setPixmap(QPixmap(":/IconAdd/general_email64.png"));
 	clEmail->hide();
 
+	clMap = new QClickableLabel(this);
+	clMap->setBorderEnabled(false);
+	clMap->setForegroundRole(QPalette::Window);
+	clMap->setPixmap(QPixmap(":/IconAdd/Maps-blue-64.png"));
+	clMap->hide();
+
 	QObject::connect(clZoomin, SIGNAL(clicked()), this, SLOT(zoominView()));
 	QObject::connect(clZoomout, SIGNAL(clicked()), this, SLOT(zoomoutView()));
 	QObject::connect(clNext, SIGNAL(clicked()), SLOT(loadNextNote()));
 	QObject::connect(clPrev, SIGNAL(clicked()), SLOT(loadPrevNote()));
 	QObject::connect(clEdit, SIGNAL(clicked()), SLOT(startEditor()));
 	QObject::connect(clEmail, SIGNAL(clicked()), SLOT(emailNote()));
+	QObject::connect(clMap, SIGNAL(clicked()), SLOT(showNoteMap()));
 
 //#ifdef Q_WS_MAEMO_5
 	QObject::connect(clFullscreen, SIGNAL(clicked()), SLOT(toggleFullScreen()));
@@ -405,6 +449,8 @@ void QNoteViewWindow::displayNavigationControls()
 		clEdit->animShow(QSize(64, 64));
 		clEmail->setGeometry(16, height() / 2 + 16, 0, 0);
 		clEmail->animShow(QSize(64, 64));
+		clMap->setGeometry(16, height() / 2 - 80, 0, 0);
+		clMap->animShow(QSize(64, 64));
 
 		navigationControlTimer->start(3000);
 	}
@@ -420,6 +466,7 @@ void QNoteViewWindow::hideNavigationControls()
 	clFullscreen->animHide();
 	clEdit->animHide();
 	clEmail->animHide();
+	clMap->animHide();
 	isNavControlsVisible = false;
 }
 
