@@ -96,12 +96,29 @@ QOptionsDialog::QOptionsDialog(QWidget *parent)
 
 	ui.gridLayout_2->addWidget(vbNotesViewSelection, 7, 0, 1, 2);
 
+	QStandardItemModel* mapsProviderSelectionModel = new QStandardItemModel(0, 1);
+	QMaemo5ValueButton* vbMapsProviderSelection = new QMaemo5ValueButton("Maps provider");
+	vbMapsProviderSelection->setValueLayout(QMaemo5ValueButton::ValueBesideText);
+	mapsProviderSelector = new QMaemo5ListPickSelector;
+
+	listValues.clear();
+	listValues.append("Ovi maps");
+	listValues.append("Google maps");
+
+	populateListModel(mapsProviderSelectionModel, listValues);
+
+	mapsProviderSelector->setModel(mapsProviderSelectionModel);
+	mapsProviderSelector->setCurrentIndex(settings->getMapsProvider());
+	vbMapsProviderSelection->setPickSelector(mapsProviderSelector);
+
+	ui.gridLayout_2->addWidget(vbMapsProviderSelection, 8, 0, 1, 2);
+
 	pbDeleteThumbs.setText("Clear thumbnails");
 	QObject::connect(&pbDeleteThumbs, SIGNAL(clicked()), this, SLOT(deleteThumbnails()));
-	ui.gridLayout_2->addWidget(&pbDeleteThumbs, 8, 0, 1, 2);
+	ui.gridLayout_2->addWidget(&pbDeleteThumbs, 9, 0, 1, 2);
 	pbDropDB.setText("Delete offline database");
 	QObject::connect(&pbDropDB, SIGNAL(clicked()), this, SLOT(onDropDBClick()));
-	ui.gridLayout_2->addWidget(&pbDropDB, 9, 0, 1, 2);
+	ui.gridLayout_2->addWidget(&pbDropDB, 10, 0, 1, 2);
 
 	QObject::connect(ui.pbSave, SIGNAL(clicked()), SLOT(onSaveSettingsClick()));
 	QObject::connect(this, SIGNAL(triggerDisplayError(QString, QString)), SLOT(onDisplayError(QString, QString)));
@@ -195,7 +212,7 @@ void QOptionsDialog::saveSettings()
 	}
 
 	settings->setNotesView((QvernoteSettings::NotesView)notesViewSelector->currentIndex());
-
+	settings->setMapsProvider((QvernoteSettings::MapsProvider)mapsProviderSelector->currentIndex());
 	//close();
 }
 
