@@ -13,7 +13,7 @@ class QTrashWindow : public QvernoteWindow
     Q_OBJECT
 
 public:
-    QTrashWindow(QvernoteAPI* hEvernote, QWidget *parent = 0);
+    QTrashWindow(QWidget *parent = 0);
     ~QTrashWindow();
 
     void loadNotesIntoView();
