@@ -22,6 +22,7 @@ void QvernoteSettings::Load() {
 
 	m_NotesView = (NotesView)settings.value("qvernote/notesview", NV_LIST).toInt();
 	m_NoteDisplayOrder = (NoteDisplayOrder)settings.value("qvernote/notedisplayorder", NDO_DESC).toInt();
+	m_MapsProvider = (MapsProvider)settings.value("qvernote/mapsprovider", MP_GOOGLE).toInt();
 }
 
 void QvernoteSettings::Store() {
@@ -36,6 +37,7 @@ void QvernoteSettings::Store() {
 	STORE_VAR("qvernote/online", WorkOnline);
 	STORE_VAR("qvernote/notesview", NotesView);
 	STORE_VAR("qvernote/notedisplayorder", NoteDisplayOrder);
+	STORE_VAR("qvernote/mapsprovider", MapsProvider);
 }
 
 
