@@ -32,15 +32,14 @@ QvernoteView::QvernoteView(QWidget *parent)
 	ui.gridLayout_2->addWidget(&syncWidget, 2, 0, 1, 2, Qt::AlignCenter);
 	ui.actionUse_SSL->setChecked(settings->getUseSsl());
 	ui.lvNotebookList->setVisible(false);
+	ui.pbSync->setEnabled(false);
 
 	if(!m_hEvernote->isOnline() && settings->getWorkOnline())
 	{
 		displayInformationBox("Network error occurred, working offline");
-		settings->setWorkOnline(false);
 	}
 	else
 	{
-		ui.pbSync->setEnabled(false);
 		displayInformationBox("Initializing note store. It may take a couple of minutes on first sync. Please wait...");
 	}
 
@@ -56,7 +55,7 @@ QvernoteView::QvernoteView(QWidget *parent)
 
 	QObject::connect(m_hEvernote, SIGNAL(progressUpdated(QString)), &syncWidget, SLOT(updateProgressData(QString)));
 	qRegisterMetaType<Guid>("Guid");
-	QObject::connect(m_hEvernote, SIGNAL(noteContentUpdated(Guid)), &syncWidget, SLOT(createNoteSnapshot(Guid)));
+	QObject::connect(m_hEvernote, SIGNAL(noteContentUpdated(Guid)), this, SLOT(createNoteSnapshot(Guid)));
 	//QObject::connect(this, SIGNAL(progressDataUpdated(QString)), &syncWidget, SLOT(updateProgressData(QString)));
 
 	m_pKeyGrabber = shared_ptr<QKeyGrabber>(new QKeyGrabber("", this));
@@ -88,7 +87,6 @@ void QvernoteView::loadNotebookList(QString notebookFilter)
 	setProgressIndicator(true);
 
 	//syncDlg.close();
-	ui.pbSync->setEnabled(true);
 	ui.lvNotebookList->clear();
 
 
@@ -118,6 +116,10 @@ void QvernoteView::loadNotebookList(QString notebookFilter)
 
 	syncWidget.setVisible(false);
 	ui.lvNotebookList->setVisible(true);
+
+	if(m_hEvernote->isOnline())
+		ui.pbSync->setEnabled(true);
+
 	setProgressIndicator(false);
 }
 
@@ -140,17 +142,14 @@ void QvernoteView::synchronizeNoteStore()
 {
 	setProgressIndicator(true);
 	m_pBackgroundJob->start();
+	ui.pbSync->setEnabled(false);
 
 	if(m_hEvernote->isOnline())
 	{
-		ui.pbSync->setEnabled(false);
 		displayInformationBox("Synchronizing with Evernote. Please wait...");
-		//syncDlg.exec();
-
 	}
 	else
 	{
-		ui.pbSync->setEnabled(true);
 		displayInformationBox("Unable to synchronize in offline mode");
 		setProgressIndicator(false);
 	}
@@ -175,7 +174,7 @@ void QvernoteView::openSearchDialog()
 	pDlg.exec();
 }
 
-void QvernoteView::searchNote(const QString& searchString, const std::vector<std::string>& tagGuids)
+void QvernoteView::searchNote(const QString& searchString, const std::vector<std::string>& tagGuids, const Guid& notebookGuid)
 {
 	qDebug() << "Searching" << searchString;
 	NoteFilter filter;
@@ -193,6 +192,12 @@ void QvernoteView::searchNote(const QString& searchString, const std::vector<std
 		filter.__isset.tagGuids = true;
 	}
 
+	if(notebookGuid.size() > 0)
+	{
+		filter.notebookGuid = notebookGuid;
+		filter.__isset.notebookGuid = true;
+	}
+
 	if(m_hEvernote->searchNotes(filter, 100) == false)
 	{
 		displayError("Note search failed", QString(m_hEvernote->getLastErrorString().c_str()));
@@ -293,3 +298,14 @@ void QvernoteView::clearNotebookList()
 	ui.lvNotebookList->clear();
 	m_hEvernote->loadNotebookList();
 }
+
+void QvernoteView::createNoteSnapshot(Guid guid)
+{
+	Note note;
+	note.guid = guid;
+	QvernoteAPI::Instance()->getNoteContent(note);
+	QEnmlReader* reader = new QEnmlReader(note);
+	reader->setLoadExternalReferences(false);
+	reader->parse();
+	reader->createThumbnail(true);
+}
