@@ -32,7 +32,7 @@ public slots:
     void loadNotebookList(QString notebookFilter = "");
     void deleteSelectedNotebook(QNotebookListItemWidget*);
     void openSearchDialog();
-    void searchNote(const QString& searchString, const std::vector<std::string>& tagGuids);
+    void searchNote(const QString& searchString, const std::vector<std::string>& tagGuids, const Guid& notebookGuid);
     void openDeleteNotebookWindow();
     void openAboutDialog();
     void openTrashWindow();
@@ -40,6 +40,7 @@ public slots:
     void openOptionsDialog();
     void redrawNotebookList(QString searchString);
     void clearNotebookList();
+    void createNoteSnapshot(Guid guid);
 
     void orientationChanged();
     bool backgroundJobCallback() { return backgroundInit(); }
